@@ -121,7 +121,7 @@ class AthenaPartition:
             with fm as f:
                 athena_list = f.read().decode().splitlines()
             athena_list = [{'Prefix': '{table}/{partition}/'.format(table=table, partition=partition)} for partition in athena_list]
-            partitions_list = [i for i in athena_list if i not in partitions_list]
+            partitions_list = [i for i in partitions_list if i not in athena_list]
 
         partition_string_list = []
         for i in partitions_list:
