@@ -149,7 +149,7 @@ class BaseCachedQuery(BaseCachedClass):
         :param params: a dictionary of parameters passed to each query
         :param cache_path: the path locally or on S3 to cache query results
         :param sql_archive_path: the path locally or on S3 to store archive SQL queries
-        :param sql_paths: a list of paths to search for SQL queries
+        :param sql_paths: path or a list of paths to search for SQL queries
         :param gzip: if set, then results will be compression
         :param dynamodb_lock: defaults to True, using Dynamo DB for locking in S3
         :param logger: the logger to use for this class and any newtools classes created by this class
@@ -162,7 +162,10 @@ class BaseCachedQuery(BaseCachedClass):
 
         self._sql_paths = ['sql', os.path.join(os.path.split(__file__)[0], 'sql')]
         if sql_paths is not None:
-            self._sql_paths = self._sql_paths + sql_paths
+            if not isinstance(sql_paths, list):
+                sql_paths = [sql_paths]
+            self._sql_paths = sql_paths + self._sql_paths
+
 
         self._archive_path = sql_archive_path
         self._aws_lock = DynamoDogLock if dynamodb_lock else DoggoLock
