@@ -1,8 +1,5 @@
-"""
-(c) Dativa 2012-2020, all rights reserved
-
-This code is licensed under MIT license (see license.txt for details)
-"""
+# (c) Deductive 2012-2020, all rights reserved
+# This code is licensed under MIT license (see license.txt for details)
 
 import os
 import shutil
@@ -64,7 +61,7 @@ class TestBase(BaseTest):
     """
 
     def test_import_retry(self):
-        @optional_imports.AwsRetry.backoff()
+        @optional_imports.AWSRetry.backoff()
         def banana():
             pass
 
@@ -81,12 +78,11 @@ class TestBase(BaseTest):
         optional_imports.NEVER_IMPORT = True
 
         my_s3fs = optional_imports.get_s3fs()
-        with self.assertRaisesRegex(ImportError, "s3fs is not installed. Failed calling S3FileSystem()"):
+        with self.assertRaisesRegex(ImportError, "s3fs is not installed. Failed getting S3FileSystem()"):
             my_s3fs.S3FileSystem.read_timeout = 600
 
-        with self.assertRaisesRegex(ImportError,
-                                    "dativa.tools.SqlClient is not installed. Failed calling dativa.tools.SqlClient()"):
-            optional_imports.get_sql_client()(1, 2, 3)
+        with self.assertRaisesRegex(ImportError, "s3fs is not installed. Failed calling s3fs()"):
+            my_s3fs()(1, 2, 3)
 
         optional_imports.NEVER_IMPORT = False
 
